h3_dart_plus library
Classes
- AngleConverter
- Converter between radians and degrees
- CoordIJ
- Coordinates as an {i, j} pair
- Geojson2H3
- Provides access to Geojson2H3 functions.
- H3
- Provides access to H3 functions.
- H3AngleConverter
- Converts radians to degrees and vice versa using H3's radsToDegs and degsToRads methods
- H3Factory
- LatLng
- A pair of latitude and longitude coordinates in degrees
- LatLngConverter
- Converter between LatLng and LatLngRadians
- LatLngRadians
- A pair of latitude and longitude coordinates in radians
- NativeAngleConverter
- Converts radians to degrees and vice versa using dart mathematic
- Polygon
- A polygon representation following the H3 specification.
Extensions
- LatLngConverterToDegreeExtension on LatLngRadians
- Extension to convert LatLngRadians to LatLng
- LatLngConverterToRadianExtension on LatLng
- Extension to convert LatLng to LatLngRadians